@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use Moo;
 use strictures 2;
@@ -90,7 +90,7 @@ sub _build__database {
 sub BUILD {
     my ( $self, $args ) = @_;
     die 'Schema and database may not be used at the same time.'
-        if $self->database and $self->schema;
+        if $self->has_database and $self->has_schema;
 }
 
 1;
@@ -107,7 +107,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -129,9 +129,10 @@ version 0.0102
 =head1 DESCRIPTION
 
 C<Test::SQLite> is loosely inspired by L<Test::PostgreSQL> and
-L<Test::mysqld>, but is limited to setup/teardown of the test db
-given a B<database> or B<schema> SQL, and returning the database
-B<DBH> handle or B<DSN> connection string.
+L<Test::mysqld>, and creates a temporary db to use in tests.  Unlike
+those modules, it is limited to setup/teardown of the test db given a
+B<database> or B<schema> SQL file.  Also this module will return the
+database B<dbh> handle and B<dsn> connection string.
 
 =head1 ATTRIBUTES
 
